@@ -784,7 +784,7 @@ proc OCCDoc_MakeDoxyfile {docType outDir tagFileDir {doxyFileName} {generatorMod
     puts $doxyFile "PROJECT_NUMBER         = $occt_version"
     puts $doxyFile "OUTPUT_DIRECTORY       = $outDir/."
     puts $doxyFile "GENERATE_TAGFILE       = $outDir/${name}.tag"
-
+    set searchMode "local"
     if { [string tolower $searchMode] == "none" } {
       puts $doxyFile "SEARCHENGINE           = NO"
       puts $doxyFile "SERVER_BASED_SEARCH    = NO"
@@ -835,6 +835,7 @@ proc OCCDoc_MakeDoxyfile {docType outDir tagFileDir {doxyFileName} {generatorMod
     puts $doxyFile "PROJECT_NUMBER         = $occt_version"
     puts $doxyFile "OUTPUT_DIRECTORY       = $outDir/."
     puts $doxyFile "PROJECT_LOGO           = [OCCDoc_GetDoxDir]/resources/occ_logo.png"
+    puts $doxyFile "EXAMPLE_PATH           = [OCCDoc_GetSourceDir $productsPath]"
 
     set PARAM_INPUT "INPUT                 ="
     set PARAM_IMAGEPATH "IMAGE_PATH        = [OCCDoc_GetDoxDir]/resources/ "
@@ -864,6 +865,7 @@ proc OCCDoc_MakeDoxyfile {docType outDir tagFileDir {doxyFileName} {generatorMod
           puts $doxyFile "TAGFILES               = $tagFileDir/OCCT.tag=../../refman/html"
         }
       }
+      set searchMode "local"
       # HTML Search engine options
       if { [string tolower $searchMode] == "none" } {
         puts $doxyFile "SEARCHENGINE           = NO"
