@@ -24,13 +24,13 @@ BUILD_ADDITIONAL_TOOLKITS=
 BUILD_DOC_Overview=OFF
 BUILD_Inspector=OFF
 BUILD_LIBRARY_TYPE=Shared
-BUILD_PATCH=
 BUILD_RELEASE_DISABLE_EXCEPTIONS=ON
 BUILD_WITH_DEBUG=OFF
 BUILD_ENABLE_FPE_SIGNAL_HANDLER=ON
 
 BUILD_MODULE_ApplicationFramework=ON
 BUILD_MODULE_DataExchange=ON
+BUILD_MODULE_DETools=OFF
 BUILD_MODULE_Draw=ON
 BUILD_MODULE_ModelingAlgorithms=ON
 BUILD_MODULE_ModelingData=ON
@@ -63,12 +63,12 @@ cmake -G "Unix Makefiles" \
   -D BUILD_LIBRARY_TYPE:STRING=$BUILD_LIBRARY_TYPE \
   -D BUILD_MODULE_ApplicationFramework:BOOL=$BUILD_MODULE_ApplicationFramework \
   -D BUILD_MODULE_DataExchange:BOOL=$BUILD_MODULE_DataExchange \
+  -D BUILD_MODULE_DETools:BOOL=$BUILD_MODULE_DETools \
   -D BUILD_MODULE_Draw:BOOL=$BUILD_MODULE_Draw \
   -D BUILD_MODULE_FoundationClasses:BOOL=ON \
   -D BUILD_MODULE_ModelingAlgorithms:BOOL=$BUILD_MODULE_ModelingAlgorithms \
   -D BUILD_MODULE_ModelingData:BOOL=$BUILD_MODULE_ModelingData \
   -D BUILD_MODULE_Visualization:BOOL=$BUILD_MODULE_Visualization \
-  -D BUILD_PATCH:PATH="$BUILD_PATCH" \
   -D BUILD_RELEASE_DISABLE_EXCEPTIONS:BOOL=$BUILD_RELEASE_DISABLE_EXCEPTIONS \
   -D BUILD_WITH_DEBUG:BOOL=$BUILD_WITH_DEBUG \
   -D BUILD_ENABLE_FPE_SIGNAL_HANDLER:BOOL=$BUILD_ENABLE_FPE_SIGNAL_HANDLER \
