@@ -51,10 +51,10 @@
 #pragma comment(lib, "TKV3d.lib")
 #pragma comment(lib, "TKOpenGl.lib")
 #pragma comment(lib, "TKD3dHost.lib")
-#pragma comment(lib, "TKIGES.lib")
-#pragma comment(lib, "TKSTEP.lib")
-#pragma comment(lib, "TKStl.lib")
-#pragma comment(lib, "TKVrml.lib")
+#pragma comment(lib, "TKDEIGES.lib")
+#pragma comment(lib, "TKDESTEP.lib")
+#pragma comment(lib, "TKDESTL.lib")
+#pragma comment(lib, "TKDEVRML.lib")
 #pragma comment(lib, "TKLCAF.lib")
 
 #pragma comment(lib, "D3D9.lib")
@@ -263,7 +263,10 @@ public:
   {
     if (!myAISContext().IsNull())
     {
-      myAISContext()->Select (theX1, theY1, theX2, theY2, myView(), Standard_True);
+      myAISContext()->SelectRectangle (Graphic3d_Vec2i (theX1, theY1),
+                                       Graphic3d_Vec2i (theX2, theY2),
+                                       myView());
+      myAISContext()->UpdateCurrentViewer();
     }
   }
 
@@ -274,7 +277,8 @@ public:
   {
     if (!myAISContext().IsNull())
     {
-      myAISContext()->Select (Standard_True);
+      myAISContext()->SelectDetected();
+      myAISContext()->UpdateCurrentViewer();
     }
   }
 
@@ -296,7 +300,11 @@ public:
   {
     if (!myAISContext().IsNull() && !myView().IsNull())
     {
-      myAISContext()->ShiftSelect (theX1, theY1, theX2, theY2, myView(), Standard_True);
+      myAISContext()->SelectRectangle (Graphic3d_Vec2i (theX1, theY1),
+                                       Graphic3d_Vec2i (theX2, theY2),
+                                       myView(),
+                                       AIS_SelectionScheme_XOR);
+      myAISContext()->UpdateCurrentViewer();
     }
   }
 
@@ -307,7 +315,8 @@ public:
   {
     if (!myAISContext().IsNull())
     {
-      myAISContext()->ShiftSelect (Standard_True);
+      myAISContext()->SelectDetected (AIS_SelectionScheme_XOR);
+      myAISContext()->UpdateCurrentViewer();
     }
   }
 
