@@ -3,6 +3,10 @@
 #Category: Visualization
 #Title: Ray tracing
 
+# Ray-Tracing doesn't work with Compatible Profile on macOS
+pload VISUALIZATION
+if { $::tcl_platform(os) == "Darwin" } { vcaps -core }
+
 # make bottle by calling another script
 source [file join [file dirname [info script]] bottle.tcl]
 
@@ -27,7 +31,7 @@ vsetcolor glass brown
 vsettransparency glass 0.6
 
 # add light source for shadows
-vlight new spot pos -100 -100 300
+vlight spot -type SPOT -pos -100 -100 300
 
 # set white background and fit view
 vbackground -color WHITE
