@@ -14,8 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <AdvApprox_Cutting.hxx>
 
-AdvApprox_Cutting::~AdvApprox_Cutting()
-{}
+AdvApprox_Cutting::~AdvApprox_Cutting() {}
