@@ -14,21 +14,17 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <AdvApprox_DichoCutting.hxx>
 #include <Precision.hxx>
 
-AdvApprox_DichoCutting::AdvApprox_DichoCutting()
-{
-}
+AdvApprox_DichoCutting::AdvApprox_DichoCutting() {}
 
 Standard_Boolean AdvApprox_DichoCutting::Value(const Standard_Real a,
-						const Standard_Real b,
-						Standard_Real& cuttingvalue) const
+                                               const Standard_Real b,
+                                               Standard_Real&      cuttingvalue) const
 {
-//  longueur minimum d'un intervalle pour F(U,V) : EPS1=1.e-9 (cf.MEPS1)
-  Standard_Real lgmin = 10*Precision::PConfusion();
-  cuttingvalue = (a+b) / 2;
-  return (Abs(b-a)>=2*lgmin);
+  //  longueur minimum d'un intervalle pour F(U,V) : EPS1=1.e-9 (cf.MEPS1)
+  constexpr Standard_Real lgmin = 10 * Precision::PConfusion();
+  cuttingvalue                  = (a + b) / 2;
+  return (Abs(b - a) >= 2 * lgmin);
 }
-
