@@ -14,13 +14,8 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <AppBlend_Approx.hxx>
 
-//=======================================================================
-//function : AppBlend_Approx
-//purpose  : Destructor
-//=======================================================================
-AppBlend_Approx::~AppBlend_Approx()
-{
-}
+//=================================================================================================
+
+AppBlend_Approx::~AppBlend_Approx() {}
