@@ -12,26 +12,21 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <AppParCurves_ConstraintCouple.hxx>
 
-AppParCurves_ConstraintCouple::
-  AppParCurves_ConstraintCouple()
-: myIndex(-1),
-  myConstraint(AppParCurves_NoConstraint)
+AppParCurves_ConstraintCouple::AppParCurves_ConstraintCouple()
+    : myIndex(-1),
+      myConstraint(AppParCurves_NoConstraint)
 {
 }
 
-
-AppParCurves_ConstraintCouple::
-  AppParCurves_ConstraintCouple(const Standard_Integer TheIndex,
-				const AppParCurves_Constraint Cons)
+AppParCurves_ConstraintCouple::AppParCurves_ConstraintCouple(const Standard_Integer        TheIndex,
+                                                             const AppParCurves_Constraint Cons)
 {
-  myIndex = TheIndex;
+  myIndex      = TheIndex;
   myConstraint = Cons;
 }
 
-
 Standard_Integer AppParCurves_ConstraintCouple::Index() const
 {
   return myIndex;
@@ -42,15 +37,12 @@ AppParCurves_Constraint AppParCurves_ConstraintCouple::Constraint() const
   return myConstraint;
 }
 
-
 void AppParCurves_ConstraintCouple::SetIndex(const Standard_Integer TheIndex)
 {
   myIndex = TheIndex;
 }
 
-void AppParCurves_ConstraintCouple::
-  SetConstraint(const AppParCurves_Constraint Cons)
+void AppParCurves_ConstraintCouple::SetConstraint(const AppParCurves_Constraint Cons)
 {
   myConstraint = Cons;
 }
-
