@@ -17,11 +17,9 @@
 #include <Approx_FitAndDivide2d.hxx>
 
 #include <AppParCurves_MultiCurve.hxx>
- 
 
 #define MultiLine AppCont_Function
 #define MultiLine_hxx <AppCont_Function.hxx>
 #define Approx_ComputeCLine Approx_FitAndDivide2d
 #define Approx_ComputeCLine_hxx <Approx_FitAndDivide2d.hxx>
-#include <Approx_ComputeCLine.gxx>
-
+#include "../Approx/Approx_ComputeCLine.gxx"
