@@ -53,26 +53,23 @@
 
 #include <algorithm>
 
-static
-  void OwnInternalShapes(const TopoDS_Shape& ,
-                         TopTools_IndexedMapOfShape& );
+static void OwnInternalShapes(const TopoDS_Shape&, TopTools_IndexedMapOfShape&);
 
+//=================================================================================================
 
-//=======================================================================
-//function : FillImagesSolids
-//purpose  : 
-//=======================================================================
 void BOPAlgo_Builder::FillImagesSolids(const Message_ProgressRange& theRange)
 {
   Standard_Integer i = 0, aNbS = myDS->NbSourceShapes();
-  for (i = 0; i < aNbS; ++i) {
+  for (i = 0; i < aNbS; ++i)
+  {
     const BOPDS_ShapeInfo& aSI = myDS->ShapeInfo(i);
     if (aSI.ShapeType() == TopAbs_SOLID)
     {
       break;
     }
   }
-  if (i >= aNbS) {
+  if (i >= aNbS)
+  {
     return;
   }
 
@@ -94,12 +91,11 @@ void BOPAlgo_Builder::FillImagesSolids(const Message_ProgressRange& theRange)
   // Fill solids with internal parts
   FillInternalShapes(aPS.Next());
 }
-//=======================================================================
-//function : FillIn3DParts
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids,
-                                    const Message_ProgressRange& theRange)
+                                    const Message_ProgressRange&  theRange)
 {
   Message_ProgressScope aPS(theRange, NULL, 2);
 
@@ -128,7 +124,7 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
       return;
     }
 
-    const TopoDS_Shape& aS = aSI.Shape();
+    const TopoDS_Shape&         aS    = aSI.Shape();
     const TopTools_ListOfShape* pLSIm = myImages.Seek(aS);
 
     if (pLSIm)
@@ -168,7 +164,7 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
     {
       return;
     }
-    const TopoDS_Shape& aS = aSI.Shape();
+    const TopoDS_Shape& aS     = aSI.Shape();
     const TopoDS_Solid& aSolid = (*(TopoDS_Solid*)(&aS));
     //
     // Bounding box for the solid aS
@@ -178,7 +174,7 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
 
     // Build Draft Solid
     TopTools_ListOfShape aLIF;
-    TopoDS_Solid aSD;
+    TopoDS_Solid         aSD;
     aBB.MakeSolid(aSD);
     BuildDraftSolid(aSolid, aSD, aLIF);
 
@@ -191,9 +187,14 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
   // Perform classification of the faces
   TopTools_IndexedDataMapOfShapeListOfShape anInParts;
 
-  BOPAlgo_Tools::ClassifyFaces(aLFaces, aLSolids, myRunParallel,
-                               myContext, anInParts, aShapeBoxMap,
-                               aSolidsIF, aPS.Next());
+  BOPAlgo_Tools::ClassifyFaces(aLFaces,
+                               aLSolids,
+                               myRunParallel,
+                               myContext,
+                               anInParts,
+                               aShapeBoxMap,
+                               aSolidsIF,
+                               aPS.Next());
 
   // Analyze the results of classification
   Standard_Integer aNbSol = aDraftSolid.Extent();
@@ -203,9 +204,9 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
     {
       return;
     }
-    const TopoDS_Solid& aSolid = TopoDS::Solid(aDraftSolid.FindKey(i));
-    const TopoDS_Solid& aSDraft = TopoDS::Solid(aDraftSolid(i));
-    const TopTools_ListOfShape& aLInFaces = anInParts.FindFromKey(aSDraft);
+    const TopoDS_Solid&         aSolid     = TopoDS::Solid(aDraftSolid.FindKey(i));
+    const TopoDS_Solid&         aSDraft    = TopoDS::Solid(aDraftSolid(i));
+    const TopTools_ListOfShape& aLInFaces  = anInParts.FindFromKey(aSDraft);
     const TopTools_ListOfShape& aLInternal = aSolidsIF.Find(aSDraft);
 
     Standard_Integer aNbIN = aLInFaces.Extent();
@@ -228,7 +229,7 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
     if (aNbInt || aNbIN)
     {
       // Combine the lists
-      TopTools_ListOfShape *pLIN  = myInParts.Bound(aSolid, TopTools_ListOfShape());
+      TopTools_ListOfShape* pLIN = myInParts.Bound(aSolid, TopTools_ListOfShape());
 
       TopTools_ListIteratorOfListOfShape aItLS(aLInFaces);
       for (; aItLS.More(); aItLS.Next())
@@ -240,102 +241,117 @@ void BOPAlgo_Builder::FillIn3DParts(TopTools_DataMapOfShapeShape& theDraftSolids
     }
   }
 }
-//=======================================================================
-//function : BuildDraftSolid
-//purpose  : 
-//=======================================================================
-void BOPAlgo_Builder::BuildDraftSolid(const TopoDS_Shape& theSolid,
-                                      TopoDS_Shape& theDraftSolid,
+
+//=================================================================================================
+
+void BOPAlgo_Builder::BuildDraftSolid(const TopoDS_Shape&   theSolid,
+                                      TopoDS_Shape&         theDraftSolid,
                                       TopTools_ListOfShape& theLIF)
 {
-  Standard_Boolean bToReverse;
-  Standard_Integer iFlag;
-  TopAbs_Orientation aOrF, aOrSh, aOrSd;
-  TopoDS_Iterator aIt1, aIt2;
-  TopoDS_Shell aShD;
-  TopoDS_Shape aFx;
-  BRep_Builder aBB;
-  TopTools_ListIteratorOfListOfShape aItS; 
+  Standard_Boolean                   bToReverse;
+  Standard_Integer                   iFlag;
+  TopAbs_Orientation                 aOrF, aOrSh, aOrSd;
+  TopoDS_Iterator                    aIt1, aIt2;
+  TopoDS_Shell                       aShD;
+  TopoDS_Shape                       aFx;
+  BRep_Builder                       aBB;
+  TopTools_ListIteratorOfListOfShape aItS;
   //
-  aOrSd=theSolid.Orientation();
+  aOrSd = theSolid.Orientation();
   theDraftSolid.Orientation(aOrSd);
   //
   aIt1.Initialize(theSolid);
-  for (; aIt1.More(); aIt1.Next()) {
-    const TopoDS_Shape& aSh=aIt1.Value();
-    if(aSh.ShapeType()!=TopAbs_SHELL) {
+  for (; aIt1.More(); aIt1.Next())
+  {
+    const TopoDS_Shape& aSh = aIt1.Value();
+    if (aSh.ShapeType() != TopAbs_SHELL)
+    {
       continue; // mb internal edges,vertices
     }
     //
-    aOrSh=aSh.Orientation();
+    aOrSh = aSh.Orientation();
     aBB.MakeShell(aShD);
     aShD.Orientation(aOrSh);
-    iFlag=0;
+    iFlag = 0;
     //
     aIt2.Initialize(aSh);
-    for (; aIt2.More(); aIt2.Next()) {
-      const TopoDS_Shape& aF=aIt2.Value();
-      aOrF=aF.Orientation();
+    for (; aIt2.More(); aIt2.Next())
+    {
+      const TopoDS_Shape& aF = aIt2.Value();
+      aOrF                   = aF.Orientation();
       //
-      if (myImages.IsBound(aF)) {
-        const TopTools_ListOfShape& aLSp=myImages.Find(aF);
+      if (myImages.IsBound(aF))
+      {
+        const TopTools_ListOfShape& aLSp = myImages.Find(aF);
         aItS.Initialize(aLSp);
-        for (; aItS.More(); aItS.Next()) {
-          aFx=aItS.Value();
+        for (; aItS.More(); aItS.Next())
+        {
+          aFx = aItS.Value();
           //
-          if (myShapesSD.IsBound(aFx)) {
+          if (myShapesSD.IsBound(aFx))
+          {
             //
-            if (aOrF==TopAbs_INTERNAL) {
+            if (aOrF == TopAbs_INTERNAL)
+            {
               aFx.Orientation(aOrF);
               theLIF.Append(aFx);
             }
-            else {
-              bToReverse=BOPTools_AlgoTools::IsSplitToReverseWithWarn
-                (aFx, aF, myContext, myReport);
-              if (bToReverse) {
+            else
+            {
+              bToReverse =
+                BOPTools_AlgoTools::IsSplitToReverseWithWarn(aFx, aF, myContext, myReport);
+              if (bToReverse)
+              {
                 aFx.Reverse();
               }
               //
-              iFlag=1;
+              iFlag = 1;
               aBB.Add(aShD, aFx);
             }
-          }//if (myShapesSD.IsBound(aFx)) {
-          else {
+          } // if (myShapesSD.IsBound(aFx)) {
+          else
+          {
             aFx.Orientation(aOrF);
-            if (aOrF==TopAbs_INTERNAL) {
+            if (aOrF == TopAbs_INTERNAL)
+            {
               theLIF.Append(aFx);
             }
-            else{
-              iFlag=1;
+            else
+            {
+              iFlag = 1;
               aBB.Add(aShD, aFx);
             }
           }
         }
-      } // if (myImages.IsBound(aF)) { 
+      } // if (myImages.IsBound(aF)) {
       //
-      else {
-        if (aOrF==TopAbs_INTERNAL) {
+      else
+      {
+        if (aOrF == TopAbs_INTERNAL)
+        {
           theLIF.Append(aF);
         }
-        else{
-          iFlag=1;
+        else
+        {
+          iFlag = 1;
           aBB.Add(aShD, aF);
         }
       }
-    } //for (; aIt2.More(); aIt2.Next()) {
+    } // for (; aIt2.More(); aIt2.Next()) {
     //
-    if (iFlag) {
-      aShD.Closed (BRep_Tool::IsClosed (aShD));
+    if (iFlag)
+    {
+      aShD.Closed(BRep_Tool::IsClosed(aShD));
       aBB.Add(theDraftSolid, aShD);
     }
-  } //for (; aIt1.More(); aIt1.Next()) {
+  } // for (; aIt1.More(); aIt1.Next()) {
 }
 
 //=======================================================================
 
 //=======================================================================
-//class : BOPAlgo_SplitSolid
-//purpose  : Auxiliary class to extend the BOPAlgo_BuilderSolid with the solid to split
+// class : BOPAlgo_SplitSolid
+// purpose  : Auxiliary class to extend the BOPAlgo_BuilderSolid with the solid to split
 //=======================================================================
 class BOPAlgo_SplitSolid : public BOPAlgo_BuilderSolid
 {
@@ -347,10 +363,7 @@ public:
   const TopoDS_Solid& Solid() const { return mySolid; }
 
   //! Sets progress range
-  void SetProgressRange(const Message_ProgressRange& theRange)
-  {
-    myRange = theRange;
-  }
+  void SetProgressRange(const Message_ProgressRange& theRange) { myRange = theRange; }
 
   // New perform method, using own progress range
   void Perform()
@@ -365,43 +378,43 @@ public:
 
 private:
   //! Disable the range enabled method
-  virtual void Perform(const Message_ProgressRange&/* theRange*/) {}
+  virtual void Perform(const Message_ProgressRange& /* theRange*/) {}
 
 private:
-  TopoDS_Solid mySolid; //!< Solid to split
+  TopoDS_Solid          mySolid; //!< Solid to split
   Message_ProgressRange myRange;
 };
 
 // Vector of Solid Builders
 typedef NCollection_Vector<BOPAlgo_SplitSolid> BOPAlgo_VectorOfBuilderSolid;
 
-//=======================================================================
-//function : BuildSplitSolids
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSolids,
-                                       const Message_ProgressRange& theRange)
+                                       const Message_ProgressRange&  theRange)
 {
-  Standard_Boolean bFlagSD;
-  Standard_Integer i, aNbS;
-  TopExp_Explorer aExp;
+  Standard_Boolean                   bFlagSD;
+  Standard_Integer                   i, aNbS;
+  TopExp_Explorer                    aExp;
   TopTools_ListIteratorOfListOfShape aIt;
   //
   Handle(NCollection_BaseAllocator) aAlr0;
-  aAlr0=NCollection_BaseAllocator::CommonBaseAllocator();
+  aAlr0 = NCollection_BaseAllocator::CommonBaseAllocator();
   //
-  TopTools_ListOfShape aSFS(aAlr0), aLSEmpty(aAlr0);
-  TopTools_MapOfShape aMFence(100, aAlr0);
-  BOPTools_MapOfSet aMST(100, aAlr0);
+  TopTools_ListOfShape         aSFS(aAlr0), aLSEmpty(aAlr0);
+  TopTools_MapOfShape          aMFence(100, aAlr0);
+  BOPTools_MapOfSet            aMST(100, aAlr0);
   BOPAlgo_VectorOfBuilderSolid aVBS;
   //
-  Message_ProgressScope aPSOuter (theRange, NULL, 10);
+  Message_ProgressScope aPSOuter(theRange, NULL, 10);
   // 0. Find same domain solids for non-interfered solids
-  aNbS=myDS->NbSourceShapes();
-  for (i=0; i<aNbS; ++i) {
-    const BOPDS_ShapeInfo& aSI=myDS->ShapeInfo(i);
+  aNbS = myDS->NbSourceShapes();
+  for (i = 0; i < aNbS; ++i)
+  {
+    const BOPDS_ShapeInfo& aSI = myDS->ShapeInfo(i);
     //
-    if (aSI.ShapeType()!=TopAbs_SOLID) {
+    if (aSI.ShapeType() != TopAbs_SOLID)
+    {
       continue;
     }
     if (UserBreak(aPSOuter))
@@ -409,11 +422,13 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
       return;
     }
     //
-    const TopoDS_Shape& aS=aSI.Shape();
-    if (!aMFence.Add(aS)) {
+    const TopoDS_Shape& aS = aSI.Shape();
+    if (!aMFence.Add(aS))
+    {
       continue;
     }
-    if(theDraftSolids.IsBound(aS)) {
+    if (theDraftSolids.IsBound(aS))
+    {
       continue;
     }
     //
@@ -422,23 +437,24 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
     aST.Add(aS, TopAbs_FACE);
     aMST.Add(aST);
     //
-  } //for (i=1; i<=aNbS; ++i) 
+  } // for (i=1; i<=aNbS; ++i)
   //
   // Build temporary map of solids images to avoid rebuilding
   // of the solids without internal faces
   TopTools_IndexedDataMapOfShapeListOfShape aSolidsIm;
   // 1. Build solids for interfered source solids
-  for (i = 0; i < aNbS; ++i) {
+  for (i = 0; i < aNbS; ++i)
+  {
     const BOPDS_ShapeInfo& aSI = myDS->ShapeInfo(i);
     if (aSI.ShapeType() != TopAbs_SOLID)
       continue;
 
-    const TopoDS_Shape& aS = aSI.Shape();
-    const TopoDS_Solid& aSolid=(*(TopoDS_Solid*)(&aS));
+    const TopoDS_Shape& aS     = aSI.Shape();
+    const TopoDS_Solid& aSolid = (*(TopoDS_Solid*)(&aS));
     if (!theDraftSolids.IsBound(aS))
       continue;
 
-    const TopoDS_Shape& aSD = theDraftSolids.Find(aS);
+    const TopoDS_Shape&         aSD   = theDraftSolids.Find(aS);
     const TopTools_ListOfShape* pLFIN = myInParts.Seek(aS);
     if (!pLFIN || pLFIN->IsEmpty())
     {
@@ -450,14 +466,16 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
     //
     // 1.1 Fill Shell Faces Set
     aExp.Init(aSD, TopAbs_FACE);
-    for (; aExp.More(); aExp.Next()) {
+    for (; aExp.More(); aExp.Next())
+    {
       const TopoDS_Shape& aF = aExp.Current();
       aSFS.Append(aF);
     }
     //
     // 1.2 Fill internal faces
     aIt.Initialize(*pLFIN);
-    for (; aIt.More(); aIt.Next()) {
+    for (; aIt.More(); aIt.Next())
+    {
       TopoDS_Shape aF = aIt.Value();
       //
       aF.Orientation(TopAbs_FORWARD);
@@ -467,15 +485,15 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
     }
     //
     // 1.3 Build new solids
-    BOPAlgo_SplitSolid& aBS=aVBS.Appended();
+    BOPAlgo_SplitSolid& aBS = aVBS.Appended();
     aBS.SetSolid(aSolid);
     aBS.SetShapes(aSFS);
     aBS.SetRunParallel(myRunParallel);
-  }//for (i=0; i<aNbS; ++i) {
+  } // for (i=0; i<aNbS; ++i) {
   //
   Standard_Integer k, aNbBS;
   //
-  aNbBS=aVBS.Length();
+  aNbBS = aVBS.Length();
   // Set progress range for each task to be run in parallel
   Message_ProgressScope aPSParallel(aPSOuter.Next(9), "Splitting solids", aNbBS);
   for (Standard_Integer iS = 0; iS < aNbBS; iS++)
@@ -485,7 +503,7 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
   }
   //
   //===================================================
-  BOPTools_Parallel::Perform (myRunParallel, aVBS);
+  BOPTools_Parallel::Perform(myRunParallel, aVBS);
   //===================================================
   if (UserBreak(aPSOuter))
   {
@@ -501,8 +519,8 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
     // assigning the solid with the warnings/errors which
     // have been generated for it.
     // Convert all errors of BuilderSolid into warnings for main report.
-    const Handle(Message_Report)& aBSReport = aBS.GetReport();
-    Message_Gravity anAlertTypes[2] = { Message_Warning, Message_Fail };
+    const Handle(Message_Report)& aBSReport       = aBS.GetReport();
+    Message_Gravity               anAlertTypes[2] = {Message_Warning, Message_Fail};
     for (Standard_Integer iGravity = 0; iGravity < 2; iGravity++)
     {
       const Message_ListOfAlert& anLAlerts = aBSReport->GetAlerts(anAlertTypes[iGravity]);
@@ -510,7 +528,8 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
       {
         Handle(Message_Alert) anAlert = itA.Value();
 
-        Handle(TopoDS_AlertWithShape) anAlertWithShape = Handle(TopoDS_AlertWithShape)::DownCast(itA.Value());
+        Handle(TopoDS_AlertWithShape) anAlertWithShape =
+          Handle(TopoDS_AlertWithShape)::DownCast(itA.Value());
         if (!anAlertWithShape.IsNull())
         {
           TopoDS_Shape aWarnShape;
@@ -531,114 +550,127 @@ void BOPAlgo_Builder::BuildSplitSolids(TopTools_DataMapOfShapeShape& theDraftSol
   aNbBS = aSolidsIm.Extent();
   for (k = 1; k <= aNbBS; ++k)
   {
-    const TopoDS_Shape& aS = aSolidsIm.FindKey(k);
+    const TopoDS_Shape&         aS   = aSolidsIm.FindKey(k);
     const TopTools_ListOfShape& aLSR = aSolidsIm(k);
     //
-    if (!myImages.IsBound(aS)) {
+    if (!myImages.IsBound(aS))
+    {
       TopTools_ListOfShape* pLSx = myImages.Bound(aS, TopTools_ListOfShape());
       //
       aIt.Initialize(aLSR);
-      for (; aIt.More(); aIt.Next()) {
+      for (; aIt.More(); aIt.Next())
+      {
         BOPTools_Set aST;
         //
-        const TopoDS_Shape& aSR=aIt.Value();
+        const TopoDS_Shape& aSR = aIt.Value();
         aST.Add(aSR, TopAbs_FACE);
         //
-        bFlagSD=aMST.Contains(aST);
+        bFlagSD = aMST.Contains(aST);
         //
-        const BOPTools_Set& aSTx=aMST.Added(aST);
-        const TopoDS_Shape& aSx=aSTx.Shape();
+        const BOPTools_Set& aSTx = aMST.Added(aST);
+        const TopoDS_Shape& aSx  = aSTx.Shape();
         pLSx->Append(aSx);
         //
         TopTools_ListOfShape* pLOr = myOrigins.ChangeSeek(aSx);
-        if (!pLOr) {
+        if (!pLOr)
+        {
           pLOr = myOrigins.Bound(aSx, TopTools_ListOfShape());
         }
         pLOr->Append(aS);
         //
-        if (bFlagSD) {
+        if (bFlagSD)
+        {
           myShapesSD.Bind(aSR, aSx);
         }
       }
     }
   }
 }
-//=======================================================================
-//function :FillInternalShapes 
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
 {
-  Standard_Integer i, j,  aNbS, aNbSI, aNbSx;
-  TopAbs_ShapeEnum aType;
-  TopAbs_State aState; 
-  TopoDS_Iterator aItS;
-  BRep_Builder aBB;
+  Standard_Integer                   i, j, aNbS, aNbSI, aNbSx;
+  TopAbs_ShapeEnum                   aType;
+  TopAbs_State                       aState;
+  TopoDS_Iterator                    aItS;
+  BRep_Builder                       aBB;
   TopTools_ListIteratorOfListOfShape aIt, aIt1;
   //
   Handle(NCollection_BaseAllocator) aAllocator;
   //-----------------------------------------------------scope f
-  aAllocator=NCollection_BaseAllocator::CommonBaseAllocator();
+  aAllocator = NCollection_BaseAllocator::CommonBaseAllocator();
   //
   TopTools_IndexedDataMapOfShapeListOfShape aMSx(100, aAllocator);
-  TopTools_IndexedMapOfShape aMx(100, aAllocator);
-  TopTools_IndexedMapOfShape aMSI(100, aAllocator);
-  TopTools_MapOfShape aMFence(100, aAllocator);
-  TopTools_MapOfShape aMSOr(100, aAllocator);
-  TopTools_ListOfShape aLSd(aAllocator);
-  TopTools_ListOfShape aLArgs(aAllocator);
-  TopTools_ListOfShape aLSC(aAllocator);
-  TopTools_ListOfShape aLSI(aAllocator);
+  TopTools_IndexedMapOfShape                aMx(100, aAllocator);
+  TopTools_IndexedMapOfShape                aMSI(100, aAllocator);
+  TopTools_MapOfShape                       aMFence(100, aAllocator);
+  TopTools_MapOfShape                       aMSOr(100, aAllocator);
+  TopTools_ListOfShape                      aLSd(aAllocator);
+  TopTools_ListOfShape                      aLArgs(aAllocator);
+  TopTools_ListOfShape                      aLSC(aAllocator);
+  TopTools_ListOfShape                      aLSI(aAllocator);
 
   Message_ProgressScope aPS(theRange, NULL, 10);
   //
   // 1. Shapes to process
   //
-  // 1.1 Shapes from pure arguments aMSI 
+  // 1.1 Shapes from pure arguments aMSI
   // 1.1.1 vertex, edge, wire
   //
-  const TopTools_ListOfShape& aArguments=myDS->Arguments();
+  const TopTools_ListOfShape& aArguments = myDS->Arguments();
   aIt.Initialize(aArguments);
-  for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aS=aIt.Value();
+  for (; aIt.More(); aIt.Next())
+  {
+    const TopoDS_Shape& aS = aIt.Value();
     BOPTools_AlgoTools::TreatCompound(aS, aLSC, &aMFence);
   }
   aIt.Initialize(aLSC);
-  for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aS=aIt.Value();
-    aType=aS.ShapeType();
-    if (aType==TopAbs_WIRE) {
+  for (; aIt.More(); aIt.Next())
+  {
+    const TopoDS_Shape& aS = aIt.Value();
+    aType                  = aS.ShapeType();
+    if (aType == TopAbs_WIRE)
+    {
       aItS.Initialize(aS);
-      for(; aItS.More(); aItS.Next()) {
-        const TopoDS_Shape& aE=aItS.Value();
-        if (aMFence.Add(aE)) {
+      for (; aItS.More(); aItS.Next())
+      {
+        const TopoDS_Shape& aE = aItS.Value();
+        if (aMFence.Add(aE))
+        {
           aLArgs.Append(aE);
         }
       }
     }
-    else if (aType==TopAbs_VERTEX || aType==TopAbs_EDGE){
+    else if (aType == TopAbs_VERTEX || aType == TopAbs_EDGE)
+    {
       aLArgs.Append(aS);
-    } 
+    }
   }
   aMFence.Clear();
   //
   aIt.Initialize(aLArgs);
-  for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aS=aIt.Value();
-    aType=aS.ShapeType();
-    if (aType==TopAbs_VERTEX || 
-        aType==TopAbs_EDGE ||
-        aType==TopAbs_WIRE) {
-      if (aMFence.Add(aS)) {
-        if (myImages.IsBound(aS)) {
-          const TopTools_ListOfShape &aLSp=myImages.Find(aS);
+  for (; aIt.More(); aIt.Next())
+  {
+    const TopoDS_Shape& aS = aIt.Value();
+    aType                  = aS.ShapeType();
+    if (aType == TopAbs_VERTEX || aType == TopAbs_EDGE || aType == TopAbs_WIRE)
+    {
+      if (aMFence.Add(aS))
+      {
+        if (myImages.IsBound(aS))
+        {
+          const TopTools_ListOfShape& aLSp = myImages.Find(aS);
           aIt1.Initialize(aLSp);
-          for (; aIt1.More(); aIt1.Next()) {
-            const TopoDS_Shape& aSp=aIt1.Value();
+          for (; aIt1.More(); aIt1.Next())
+          {
+            const TopoDS_Shape& aSp = aIt1.Value();
             aMSI.Add(aSp);
           }
         }
-        else {
+        else
+        {
           aMSI.Add(aS);
         }
       }
@@ -649,17 +681,19 @@ void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
     return;
   }
 
-  aNbSI=aMSI.Extent();
+  aNbSI = aMSI.Extent();
   //
   // 2. Internal vertices, edges from source solids
   aMFence.Clear();
   aLSd.Clear();
   //
-  aNbS=myDS->NbSourceShapes();
-  for (i=0; i<aNbS; ++i) {
-    const BOPDS_ShapeInfo& aSI=myDS->ShapeInfo(i);
+  aNbS = myDS->NbSourceShapes();
+  for (i = 0; i < aNbS; ++i)
+  {
+    const BOPDS_ShapeInfo& aSI = myDS->ShapeInfo(i);
     //
-    if (aSI.ShapeType()!=TopAbs_SOLID) {
+    if (aSI.ShapeType() != TopAbs_SOLID)
+    {
       continue;
     }
     if (UserBreak(aPS))
@@ -667,72 +701,86 @@ void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
       return;
     }
     //
-    const TopoDS_Shape& aS=aSI.Shape();
+    const TopoDS_Shape& aS = aSI.Shape();
     //
     aMx.Clear();
     OwnInternalShapes(aS, aMx);
     //
-    aNbSx=aMx.Extent();
-    for (j=1; j<=aNbSx; ++j) {
-      const TopoDS_Shape& aSi=aMx(j);
-      if (myImages.IsBound(aSi)) {
-        const TopTools_ListOfShape &aLSp=myImages.Find(aSi);
+    aNbSx = aMx.Extent();
+    for (j = 1; j <= aNbSx; ++j)
+    {
+      const TopoDS_Shape& aSi = aMx(j);
+      if (myImages.IsBound(aSi))
+      {
+        const TopTools_ListOfShape& aLSp = myImages.Find(aSi);
         aIt1.Initialize(aLSp);
-        for (; aIt1.More(); aIt1.Next()) {
-          const TopoDS_Shape& aSp=aIt1.Value();
+        for (; aIt1.More(); aIt1.Next())
+        {
+          const TopoDS_Shape& aSp = aIt1.Value();
           aMSI.Add(aSp);
         }
       }
-      else {
+      else
+      {
         aMSI.Add(aSi);
       }
     }
     //
     // build aux map from splits of solids
-    if (myImages.IsBound(aS)) {
-      const TopTools_ListOfShape &aLSp=myImages.Find(aS);
+    if (myImages.IsBound(aS))
+    {
+      const TopTools_ListOfShape& aLSp = myImages.Find(aS);
       aIt.Initialize(aLSp);
-      for (; aIt.More(); aIt.Next()) {
-        const TopoDS_Shape& aSp=aIt.Value();
-        if (aMFence.Add(aSp)) { 
+      for (; aIt.More(); aIt.Next())
+      {
+        const TopoDS_Shape& aSp = aIt.Value();
+        if (aMFence.Add(aSp))
+        {
           TopExp::MapShapesAndAncestors(aSp, TopAbs_VERTEX, TopAbs_EDGE, aMSx);
           TopExp::MapShapesAndAncestors(aSp, TopAbs_VERTEX, TopAbs_FACE, aMSx);
-          TopExp::MapShapesAndAncestors(aSp, TopAbs_EDGE  , TopAbs_FACE, aMSx);
+          TopExp::MapShapesAndAncestors(aSp, TopAbs_EDGE, TopAbs_FACE, aMSx);
           aLSd.Append(aSp);
         }
       }
     }
-    else {
-      if (aMFence.Add(aS)) {
+    else
+    {
+      if (aMFence.Add(aS))
+      {
         TopExp::MapShapesAndAncestors(aS, TopAbs_VERTEX, TopAbs_EDGE, aMSx);
         TopExp::MapShapesAndAncestors(aS, TopAbs_VERTEX, TopAbs_FACE, aMSx);
-        TopExp::MapShapesAndAncestors(aS, TopAbs_EDGE  , TopAbs_FACE, aMSx);
+        TopExp::MapShapesAndAncestors(aS, TopAbs_EDGE, TopAbs_FACE, aMSx);
         aLSd.Append(aS);
-        aMSOr.Add(aS); 
+        aMSOr.Add(aS);
       }
     }
-  }// for (i=0; i<aNbS; ++i) {
+  } // for (i=0; i<aNbS; ++i) {
   //
-  // 3. Some shapes of aMSI can be already tied with faces of 
+  // 3. Some shapes of aMSI can be already tied with faces of
   //    split solids
   aNbSI = aMSI.Extent();
-  for (i = 1; i <= aNbSI; ++i) {
+  for (i = 1; i <= aNbSI; ++i)
+  {
     const TopoDS_Shape& aSI = aMSI(i);
-    if (aMSx.Contains(aSI)) {
-      const TopTools_ListOfShape &aLSx=aMSx.FindFromKey(aSI);
-      aNbSx = aLSx.Extent();
-      if (!aNbSx) {
+    if (aMSx.Contains(aSI))
+    {
+      const TopTools_ListOfShape& aLSx = aMSx.FindFromKey(aSI);
+      aNbSx                            = aLSx.Extent();
+      if (!aNbSx)
+      {
         aLSI.Append(aSI);
       }
     }
-    else {
+    else
+    {
       aLSI.Append(aSI);
     }
   }
   //
   // 4. Just check it
   aNbSI = aLSI.Extent();
-  if (!aNbSI) {
+  if (!aNbSI)
+  {
     return;
   }
 
@@ -744,30 +792,34 @@ void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
   Message_ProgressScope aPSLoop(aPS.Next(9), "Looking for internal shapes", aLSd.Size());
 
   aIt.Initialize(aLSd);
-  for (; aIt.More(); aIt.Next(), aPSLoop.Next()) {
-    TopoDS_Solid aSd=TopoDS::Solid(aIt.Value());
+  for (; aIt.More(); aIt.Next(), aPSLoop.Next())
+  {
+    TopoDS_Solid aSd = TopoDS::Solid(aIt.Value());
     //
     aIt1.Initialize(aLSI);
-    for (; aIt1.More();) {
+    for (; aIt1.More();)
+    {
       TopoDS_Shape aSI = aIt1.Value();
       aSI.Orientation(TopAbs_INTERNAL);
       //
-      aState=BOPTools_AlgoTools::ComputeStateByOnePoint
-        (aSI, aSd, 1.e-11, myContext);
+      aState = BOPTools_AlgoTools::ComputeStateByOnePoint(aSI, aSd, 1.e-11, myContext);
       //
-      if (aState != TopAbs_IN) {
+      if (aState != TopAbs_IN)
+      {
         aIt1.Next();
         continue;
       }
       //
-      if (aMSOr.Contains(aSd)) {
+      if (aMSOr.Contains(aSd))
+      {
         // make new solid
         TopoDS_Solid aSdx;
         //
         aBB.MakeSolid(aSdx);
         aItS.Initialize(aSd);
-        for (; aItS.More(); aItS.Next()) {
-          const TopoDS_Shape& aSh=aItS.Value();
+        for (; aItS.More(); aItS.Next())
+        {
+          const TopoDS_Shape& aSh = aItS.Value();
           aBB.Add(aSdx, aSh);
         }
         //
@@ -781,15 +833,16 @@ void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
         pLOr->Append(aSd);
         //
         aMSOr.Remove(aSd);
-        aSd=aSdx;
+        aSd = aSdx;
       }
-      else {
+      else
+      {
         aBB.Add(aSd, aSI);
       }
       //
       aLSI.Remove(aIt1);
-    }//for (; aIt1.More();) {
-  }//for (; aIt.More(); aIt.Next()) {
+    } // for (; aIt1.More();) {
+  } // for (; aIt.More(); aIt.Next()) {
   //
   //-----------------------------------------------------scope t
   aLArgs.Clear();
@@ -800,19 +853,19 @@ void BOPAlgo_Builder::FillInternalShapes(const Message_ProgressRange& theRange)
   aMx.Clear();
   aMSx.Clear();
 }
-//=======================================================================
-//function : OwnInternalShapes
-//purpose  : 
-//=======================================================================
-void OwnInternalShapes(const TopoDS_Shape& theS,
-                       TopTools_IndexedMapOfShape& theMx)
+
+//=================================================================================================
+
+void OwnInternalShapes(const TopoDS_Shape& theS, TopTools_IndexedMapOfShape& theMx)
 {
   TopoDS_Iterator aIt;
   //
   aIt.Initialize(theS);
-  for (; aIt.More(); aIt.Next()) {
-    const TopoDS_Shape& aSx=aIt.Value();
-    if (aSx.ShapeType()!=TopAbs_SHELL) {
+  for (; aIt.More(); aIt.Next())
+  {
+    const TopoDS_Shape& aSx = aIt.Value();
+    if (aSx.ShapeType() != TopAbs_SHELL)
+    {
       theMx.Add(aSx);
     }
   }
