@@ -12,39 +12,29 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <BOPAlgo_ToolsProvider.hxx>
 #include <BOPAlgo_PaveFiller.hxx>
 
-//=======================================================================
-//function : Constructor
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 BOPAlgo_ToolsProvider::BOPAlgo_ToolsProvider()
-:
-  BOPAlgo_Builder(),
-  myTools(myAllocator),
-  myMapTools(100, myAllocator)
+    : BOPAlgo_Builder(),
+      myTools(myAllocator),
+      myMapTools(100, myAllocator)
 {
 }
 
-//=======================================================================
-//function : Constructor
-//purpose  : 
-//=======================================================================
-BOPAlgo_ToolsProvider::BOPAlgo_ToolsProvider
-  (const Handle(NCollection_BaseAllocator)& theAllocator)
-:
-  BOPAlgo_Builder(theAllocator),
-  myTools(myAllocator),
-  myMapTools(100, myAllocator)
+//=================================================================================================
+
+BOPAlgo_ToolsProvider::BOPAlgo_ToolsProvider(const Handle(NCollection_BaseAllocator)& theAllocator)
+    : BOPAlgo_Builder(theAllocator),
+      myTools(myAllocator),
+      myMapTools(100, myAllocator)
 {
 }
 
-//=======================================================================
-//function : Clear
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 void BOPAlgo_ToolsProvider::Clear()
 {
   BOPAlgo_Builder::Clear();
@@ -52,20 +42,16 @@ void BOPAlgo_ToolsProvider::Clear()
   myMapTools.Clear();
 }
 
-//=======================================================================
-//function : AddTool
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 void BOPAlgo_ToolsProvider::AddTool(const TopoDS_Shape& theShape)
 {
   if (myMapTools.Add(theShape))
     myTools.Append(theShape);
 }
 
-//=======================================================================
-//function : SetTools
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 void BOPAlgo_ToolsProvider::SetTools(const TopTools_ListOfShape& theShapes)
 {
   myTools.Clear();
